Learn R Programming

ergm.rank (version 4.0.0)

ergm-terms: Terms used in Exponential Family Random Graph Models for Ranks

Description

This page describes the possible terms (and hence network statistics) included in the ergm.rank package.

See the ergm-terms documentation in the ergm package for a complete description of what ERGM terms are and how they are used.

Arguments

Terms to represent network statistics included in the <code><a rd-options="=ergm.rank-package" href="/link/ergm.rank?package=ergm.rank&version=4.0.0&to=%3Dergm.rank-package" data-mini-rdoc="=ergm.rank-package::ergm.rank">ergm.rank</a></code> pacakge

All terms listed are valued. For their specific forms, see Krivitsky and Butts (2012).

These terms have a specialized interpretation, and are therefore generally prefixed by “rank.”, though they should take any valued data.

rank.deference

Deference (aversion): Measures the amount of ``deference'' in the network: configurations where an ego \(i\) ranks an alter \(j\) over another alter \(k\), but \(j\), in turn, ranks \(k\) over \(i\). A lower-than-chance value of this statistic and/or a negative coefficient implies a form of mutuality in the network.

rank.edgecov(x, attrname)

Dyadic covariates: Models the effect of a dyadic covariate on the propensity of an ego \(i\) to rank alter \(j\) highly. See the edgecov ERGM term documentation for arguments.

rank.inconsistency(x, attrname, weights, wtname, wtcenter)

(Weighted) Inconsistency: Measures the amount of disagreement between rankings of the focus network and a fixed covariate network x, by couting the number of pairwise comparisons for which the two networks disagree. x can be a network with an edge attribute attrname containing the ranks or a matrix of appropriate dimension containing the ranks. If x is not given, it defaults to the LHS network, and if attrname is not given, it defaults to the response edge attribute.

Optionally, the count can be weighted by the weights argument, which can be either a 3D \(n\times n\times n\)-array whose \((i,j,k)\)th element gives the weight for the comparison by \(i\) of \(j\) and \(k\) or a function taking three arguments, \(i\), \(j\), and \(k\), and returning the weight of this comparison. If wtcenter=TRUE, the calculated weights will be centered around their mean. wtname can be used to label this term.

rank.nodeicov(attr)

Attractiveness/Popularity covariates: Models the effect of one or more nodal covariates on the propensity of an actor to be ranked highly by the others. See the nodeicov ERGM term documentation for arguments.

rank.nonconformity(to, par)

Nonconformity: Measures the amount of ``nonconformity'' in the network: configurations where an ego \(i\) ranks an alter \(j\) over another alter \(k\), but ego \(l\) ranks \(k\) over \(j\).

This statistic has an argument to, which controls to whom an ego may conform:

"all" (the default)

Nonconformity to all egos is counted. A lower-than-chance value of this statistic and/or a negative coefficient implies a degree of consensus in the network.

"localAND"

Nonconformity of \(i\) to ego \(l\) regarding the relative ranking of \(j\) and \(k\) is only counted if \(i\) ranks \(l\) over both \(j\) and \(k\). A lower-than-chance value of this statistic and/or a negative coefficient implies a form of hierarchical transitivity in the network. This is the recommended form of local nonconformity (over "local1" and "local2").

"local1"

Nonconformity of \(i\) to ego \(l\) regarding the relative ranking of \(j\) and \(k\) is only counted if \(i\) ranks \(l\) over \(j\).

"local2"

Nonconformity of \(i\) to ego \(l\) regarding the relative ranking of \(j\) and \(k\) is only counted if \(i\) ranks \(l\) over \(k\).

References

  • Krivitsky P. N. (2012). Exponential-Family Random Graph Models for Valued Networks. Electronic Journal of Statistics, 6, 1100-1128. 10.1214/12-EJS696

  • Krivitsky PN and Butts CT (2017). Exponential-Family Random Graph Models for Rank-Order Relational Data. Sociological Methodology, 2017, 47, 68-112. 10.1177/0081175017692623

See Also

ergm-terms (from the ergm package), ergm, network, %v%, %n%