ergm.rank is a set of extensions to
package ergm to fit and simulate from
exponential-family random graph models for networks whose edge weights are
ranks. For a list of functions type help(package='ergm') and
help(package='ergm.rank')
Mainly, it implements the CompleteOrder reference measure for valued
ERGMs (documented here), and provides some
rank-order change statistics (documented here).
For a complete list of the functions, use library(help="ergm") and
library(help="ergm.rank") or read the rest of the manual.
When publishing results obtained using this package, please cite the
original authors as described in citation(package="ergm.rank").
All programs derived from this package must cite it.
This package contains functions specific to using ergm to
model networks whose dyad values are ranks. Examples include preferences,
valued ties reduced to ranks, etc..
For detailed information on how to download and install the software, go to the Statnet project website: https://statnet.org. A tutorial, support newsgroup, references and links to further resources are provided there.
Krivitsky PN (2012). Exponential-Family Random Graph Models for Valued Networks. Electronic Journal of Statistics, 2012, 6, 1100-1128. c("\Sexpr[results=rd,stage=build]tools:::Rd_expr_doi(\"#1\")", "doi:10.1214/12-EJS696")doi: 10.1214/12-EJS696
Krivitsky PN and Butts CT (2017). Exponential-Family Random Graph Models for Rank-Order Relational Data. Sociological Methodology, 2017, 47, 68-112. 10.1177/0081175017692623