This page describes the possible reference measures (baseline distributions)
for modeling rank data found in the ergm.rank package.
Each of these is specified on the RHS of a one-sided formula passed as
the reference argument to ergm.
See the ergm documentation for a complete
description of how reference measures are specified.
MCMLE.trustregionBecause Monte Carlo MLE's approximation to the likelihood becomes less
accurate as the estimate moves away from the one used for the
sample, ergm limits how far the optimization can move
the estimate for every iteration: the log-likelihood may not change
by more than MCMLE.trustregion control
parameter, which defaults to 20. This is an adequate value for
binary ERGMs, but because each dyad in a valued ERGM contains more
information, this number may be too small, resulting in
unnecessarily many iterations needed to find the MLE.
Automatically setting MCMLE.trustregion is
work in progress, but, in the meantime, you may want to set it to a
high number (e.g., 1000).
Reference measures currently available are:
CompleteOrderA uniform distribution over the possible complete orderings of the alters by each ego.
DiscUnif(a,b)A discrete uniform distribution used as a baseline distribution
for ranks. See DiscUnif
documentation in the ergm for arguments. Using
reference=~DiscUnif(1,n-1) (for network size n) can
be used to model weak orderings, though this approach is currently
untested. Note that it entails a specific assumption about actors'
propensity to rank.
Krivitsky PN (2012). Exponential-Family Random Graph Models for Valued Networks. Electronic Journal of Statistics, 2012, 6, 1100-1128. 10.1214/12-EJS696
Krivitsky PN and Butts CT (2017). Exponential-Family Random Graph Models for Rank-Order Relational Data. Sociological Methodology, 2017, 47, 68-112. 10.1177/0081175017692623
ergm, network, %v%, %n%, sna, summary.ergm, print.ergm